@@ -13,7 +13,7 @@ use Time::Piece ();
 
 has 'mysql';
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 sub dequeue {
   my ($self, $worker_id, $wait, $options) = @_;
@@ -1004,7 +1004,7 @@ Minion::Backend::mysql
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -1526,12 +1526,14 @@ ALTER TABLE minion_workers ADD COLUMN status MEDIUMBLOB;
 ALTER TABLE minion_jobs ADD COLUMN notes MEDIUMBLOB;
 CREATE TABLE IF NOT EXISTS minion_locks (
   id      SERIAL NOT NULL PRIMARY KEY,
-  name    VARCHAR(200) NOT NULL,
+  -- InnoDB index prefix limit is 767 bytes, and if you're using utf8mb4
+  -- that makes 767/4 = 191 characters
+  name    VARCHAR(191) NOT NULL,
   expires TIMESTAMP NOT NULL,
   INDEX (name, expires)
 );
 DELIMITER //
-CREATE FUNCTION minion_lock( $1 VARCHAR(200), $2 INTEGER, $3 INTEGER) RETURNS BOOL
+CREATE FUNCTION minion_lock( $1 VARCHAR(191), $2 INTEGER, $3 INTEGER) RETURNS BOOL
 BEGIN
   DECLARE new_expires TIMESTAMP DEFAULT DATE_ADD( NOW(), INTERVAL 1*$2 SECOND );
   DELETE FROM minion_locks WHERE expires < NOW();
